@@ -25,6 +25,7 @@
 #include <err.h>
 #include <stdint.h>
 #include <X11/Xlib.h>
+#include <time.h>
 #include "cfgfile.h"
 #include "wpset.h"
 #include "setts.h"
@@ -33,17 +34,39 @@
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if display is present, exit if it is not.
+ *
+ * @return none
  */
-void
+static int
 check_display (void)
 {
     Display *display;
 
-    display = XOpenDisplay (NULL);
-    if (display == NULL) {
-        errx (EXIT_FAILURE, "Could not detect display");
-    }
+    if ((display = XOpenDisplay (NULL)) == NULL)
+        return 0;
     XCloseDisplay(display);
+    return 1;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Sleep for 500 milliseconds.
+ */
+void sleep500 (void)
+{
+    struct timespec ts = {0, 500000000};
+
+    nanosleep(&ts, NULL);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check if display is present, exit if it is not.
+ */
+#include <stdio.h>
+void
+check_display_exit (void)
+{
+    if (!check_display ())
+        errx (EXIT_FAILURE, "Could not detect display");
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -53,9 +76,8 @@ check_display (void)
 void
 check_config_file (char **s_file)
 {
-    if (cfgfile_config_file_stuff (s_file, 0) != ERR_OK) {
+    if (cfgfile_config_file_stuff (s_file, 0) != ERR_OK)
         exit (EXIT_FAILURE);
-    }
 }
 /*----------------------------------------------------------------------------*/
 /**
