@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date May 05, 2020
+ * @date May 17, 2020
  *
- * @version 1.4.5
+ * @version 1.4.6
  *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -387,8 +387,6 @@ get_wallpaper_list (GtkWidget *gw_view,
     GSList     *gsl_iinfo1 = NULL; /* List of ImageInfo data */
     GSList     *gsl_iinfo  = NULL; /* Temp list for data */
     const char *s_val      = NULL; /* Full file path */
-    char       *s_name     = NULL; /* Unique name for background file */
-    size_t      ui_no      = 0;    /* Number to append to name */
 
     /* get ImageInfo list of TreeView files */
     gsl_iinfo1 = treeview_get_data (gw_view);
@@ -401,11 +399,8 @@ get_wallpaper_list (GtkWidget *gw_view,
 
         ii_info = gsl_iinfo->data;
         s_val   = ii_info->s_full_path;
-        s_name  = str_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
-                                        ui_no++);
-        st_sett = setting_new_string (s_val, s_name);
-
-        free (s_name);
+        st_sett = setting_new_string (s_val, NULL);
+        
         stlist_insert_setting_to_array (st_list, st_sett,
                                         get_setting_name (SETTING_WALL_ARRAY));
         gsl_iinfo = gsl_iinfo->next;
@@ -632,11 +627,10 @@ event_set_wallpaper_pressed (const DialogData *dd_data)
     if (gtk_tree_model_get_iter (gtm_model, &gti_iter, gl_list->data)) {
 
         ii_info = treemodel_get_data (gtm_model, gti_iter);
-        s_cmd = gtk_entry_get_text (GTK_ENTRY (dd_data->gw_command));
-
-        i_err = wallpaper_dialog_set (s_cmd,
-                                      imageinfo_get_full_name (ii_info),
-                                      dialogdata_get_cfg_file (dd_data));
+        s_cmd   = gtk_entry_get_text (GTK_ENTRY (dd_data->gw_command));
+        i_err   = wallpaper_dialog_set (s_cmd,
+                                        imageinfo_get_full_name (ii_info),
+                                        dialogdata_get_cfg_file (dd_data));
         if (i_err != ERR_OK) {
             message_dialog_error (dd_data->gw_window, err_get_message (i_err));
         }
@@ -657,7 +651,6 @@ event_save_settings_pressed (const DialogData *dd_data)
     st_list = widgets_get_settings (dd_data);
     i_err   = settings_check_update_file (st_list,
                                           dialogdata_get_cfg_file (dd_data));
-
     stlist_free (st_list);
 
     if (i_err != ERR_OK) {
@@ -701,7 +694,6 @@ event_treeview_key_press (GtkWidget        *widget __attribute__ ((unused)),
     if (event->keyval == GDK_KEY_Delete) {
         treeview_remove_selected (dd_data->gw_view);
     }
-
     return FALSE;
 }
 /*----------------------------------------------------------------------------*/
